@@ -18,20 +18,17 @@ from functools import cache
 from pathlib import Path
 from tempfile import NamedTemporaryFile
 from typing import TYPE_CHECKING, Any
-from unittest import mock
 
-import ansible.inventory.manager
-from ansible.config.manager import ConfigManager
 from ansible.errors import AnsibleError
-from ansible.parsing.dataloader import DataLoader
 from ansible.parsing.splitter import split_args
-from ansible.parsing.yaml.constructor import AnsibleMapping
 from ansible.plugins.loader import add_all_plugin_dirs
 from ansible_compat.runtime import AnsibleWarning
+from ruamel.yaml.parser import ParserError as RuamelParserError
+from yaml.parser import ParserError
+from yaml.scanner import ScannerError
 
 import ansiblelint.skip_utils
 import ansiblelint.utils
-from ansiblelint.app import App, get_app
 from ansiblelint.constants import States
 from ansiblelint.errors import LintWarning, MatchError, WarnSource
 from ansiblelint.file_utils import (
@@ -43,6 +40,10 @@ from ansiblelint.file_utils import (
 from ansiblelint.logger import timed_info
 from ansiblelint.rules.syntax_check import OUTPUT_PATTERNS
 from ansiblelint.text import strip_ansi_escape
+from ansiblelint.types import (  # pyright: ignore[reportAttributeAccessIssue]
+    AnsibleJSON,
+    AnsibleMapping,  # pyright: ignore[reportAttributeAccessIssue]
+)
 from ansiblelint.utils import (
     PLAYBOOK_DIR,
     HandleChildren,
@@ -54,6 +55,7 @@ if TYPE_CHECKING:
     from collections.abc import Callable, Generator
 
     from ansiblelint._internal.rules import BaseRule
+    from ansiblelint.app import App
     from ansiblelint.config import Options
     from ansiblelint.constants import FileType
     from ansiblelint.rules import RulesCollection
@@ -115,7 +117,7 @@ class Runner:
             checked_files = set()
         self.checked_files = checked_files
 
-        self.app = get_app(cached=True)
+        self.app = self.rules.app
 
     def _update_exclude_paths(self, exclude_paths: list[str]) -> None:
         if exclude_paths:
@@ -175,7 +177,7 @@ class Runner:
                 # For the moment we are ignoring deprecation warnings as Ansible
                 # modules outside current content can generate them and user
                 # might not be able to do anything about them.
-                if warn.category is DeprecationWarning:
+                if warn.category is DeprecationWarning:  # pragma: no cover
                     continue
                 if warn.category is LintWarning:
                     if isinstance(warn.source, WarnSource):
@@ -203,7 +205,7 @@ class Runner:
                     warn.category.__name__,
                     warn.message,
                 )
-        return matches
+        return sorted(matches)
 
     def _run(self) -> list[MatchError]:
         """Run the linting (inner loop)."""
@@ -217,14 +219,33 @@ class Runner:
                 self.lintables.remove(lintable)
                 continue
             if isinstance(lintable.data, States) and lintable.exc:
+                line = 1
+                column = None
+                detail = ""
+                sub_tag = ""
                 lintable.exc.__class__.__name__.lower()
+                message = None
+                if lintable.exc.__cause__ and isinstance(
+                    lintable.exc.__cause__,
+                    ScannerError | ParserError | RuamelParserError,
+                ):
+                    sub_tag = "yaml"
+                    if isinstance(lintable.exc.args, tuple):
+                        message = lintable.exc.args[0]
+                    detail = lintable.exc.__cause__.problem
+                    if lintable.exc.__cause__.problem_mark:
+                        line = lintable.exc.__cause__.problem_mark.line + 1
+                        column = lintable.exc.__cause__.problem_mark.column + 1
+
                 matches.append(
                     MatchError(
                         lintable=lintable,
-                        message=str(lintable.exc),
-                        details=str(lintable.exc.__cause__),
+                        message=message or str(lintable.exc),
+                        details=detail or str(lintable.exc.__cause__),
                         rule=self.rules["load-failure"],
-                        tag=f"load-failure[{lintable.exc.__class__.__name__.lower()}]",
+                        lineno=line,
+                        column=column,
+                        tag=f"load-failure[{sub_tag or lintable.exc.__class__.__name__.lower()}]",
                     ),
                 )
                 lintable.stop_processing = True
@@ -251,7 +272,7 @@ class Runner:
 
             for lintable in self.lintables:
                 if (
-                    lintable.kind not in ("playbook", "role")
+                    lintable.kind not in ("playbook", "role", "pattern")
                     or lintable.stop_processing
                 ):
                     continue
@@ -274,13 +295,28 @@ class Runner:
         # do our processing only when ansible syntax check passed in order
         # to avoid causing runtime exceptions. Our processing is not as
         # resilient to be able process garbage.
-        matches.extend(self._emit_matches(files))
-
+        matches.extend(
+            self._emit_matches([file for file in files if not file.failed()])
+        )
+        # mark failed failed lintables as stop processing in order to avoid
+        # duplicated errors from further processing of the other rules
+        for match in matches:
+            if match.lintable.failed():
+                match.lintable.stop_processing = True
+                # Look into making lintables singletons to avoid having to update them
+                for lintable in self.lintables:
+                    if lintable == match.lintable:
+                        lintable.stop_processing = True
+                        break
         # remove duplicates from files list
-        files = [value for n, value in enumerate(files) if value not in files[:n]]
-
+        files = list(dict.fromkeys(files))
         for file in self.lintables:
-            if file in self.checked_files or not file.kind or file.failed():
+            if (
+                file in self.checked_files
+                or not file.kind
+                or file.failed()
+                or file.stop_processing
+            ):
                 continue
             _logger.debug(
                 "Examining %s of type %s",
@@ -300,7 +336,7 @@ class Runner:
 
         return sorted(set(matches))
 
-    # pylint: disable=too-many-locals
+    # pylint: disable=too-many-locals,too-many-statements
     def _get_ansible_syntax_check_matches(
         self,
         lintable: Lintable,
@@ -332,7 +368,6 @@ class Runner:
     - ansible.builtin.import_role:
         name: {lintable.path.expanduser()!s}
 """
-                # pylint: disable=consider-using-with
                 fh = tempfile.NamedTemporaryFile(  # noqa: SIM115
                     mode="w",
                     suffix=".yml",
@@ -344,17 +379,15 @@ class Runner:
                 playbook_path = fh.name
             else:
                 playbook_path = str(lintable.path.expanduser())
+            # To avoid noisy warnings we pass localhost as current inventory:
+            # [WARNING]: No inventory was parsed, only implicit localhost is available
+            # [WARNING]: provided hosts list is empty, only localhost is available. Note that the implicit localhost does not match 'all'
             cmd = [
                 "ansible-playbook",
-                *[
-                    inventory_opt
-                    for inventory_opts in [
-                        ("-i", inventory_file)
-                        for inventory_file in self._get_inventory_files(app)
-                    ]
-                    for inventory_opt in inventory_opts
-                ],
                 "--syntax-check",
+                "-vv",  # needed or ansible-core will fail to mention the loaded file with includes:
+                # statically imported: /foo/bar/malformed.yml
+                # ERROR! A malformed block was encountered while loading a block. ..."
                 playbook_path,
             ]
             if app.options.extra_vars:
@@ -390,7 +423,7 @@ class Runner:
             stdout = strip_ansi_escape(run.stdout)
             if stderr:
                 details = stderr
-                if stdout:
+                if stdout:  # pragma: no cover
                     details += "\n" + stdout
             else:
                 details = stdout
@@ -442,6 +475,7 @@ class Runner:
                     f"Unexpected error code {run.returncode} from "
                     f"execution of: {' '.join(cmd)}"
                 )
+                filename.failed()
                 results.append(
                     MatchError(
                         message=message,
@@ -458,62 +492,6 @@ class Runner:
             fh.close()
         return results
 
-    def _get_inventory_files(self, app: App) -> list[str]:
-        config_mgr = ConfigManager()
-        ansible_cfg_inventory = config_mgr.get_config_value(
-            "DEFAULT_HOST_LIST",
-        )
-        if app.options.inventory or ansible_cfg_inventory != [
-            config_mgr.get_configuration_definitions()["DEFAULT_HOST_LIST"].get(
-                "default",
-            ),
-        ]:
-            inventory_files = [
-                inventory_file
-                for inventory_list in [
-                    # creates nested inventory list
-                    (inventory.split(",") if "," in inventory else [inventory])
-                    for inventory in (
-                        app.options.inventory
-                        if app.options.inventory
-                        else ansible_cfg_inventory
-                    )
-                ]
-                for inventory_file in inventory_list
-            ]
-
-            # silence noise when using parse_source
-            with mock.patch.object(
-                ansible.inventory.manager,
-                "display",
-                mock.Mock(),
-            ):
-                for inventory_file in inventory_files:
-                    if not Path(inventory_file).exists():
-                        _logger.warning(
-                            "Unable to use %s as an inventory source: no such file or directory",
-                            inventory_file,
-                        )
-                    elif os.access(
-                        inventory_file,
-                        os.R_OK,
-                    ) and not ansible.inventory.manager.InventoryManager(
-                        DataLoader(),
-                    ).parse_source(
-                        inventory_file,
-                    ):
-                        _logger.warning(
-                            "Unable to parse %s as an inventory source",
-                            inventory_file,
-                        )
-        else:
-            # To avoid noisy warnings we pass localhost as current inventory:
-            # [WARNING]: No inventory was parsed, only implicit localhost is available
-            # [WARNING]: provided hosts list is empty, only localhost is available. Note that the implicit localhost does not match 'all'
-            inventory_files = ["localhost"]
-
-        return inventory_files
-
     def _filter_excluded_matches(self, matches: list[MatchError]) -> list[MatchError]:
         return [
             match
@@ -527,6 +505,8 @@ class Runner:
         while visited != self.lintables:
             for lintable in self.lintables - visited:
                 visited.add(lintable)
+                if lintable.failed():
+                    continue
                 if not lintable.path.exists():
                     continue
                 try:
@@ -549,11 +529,12 @@ class Runner:
 
     def find_children(self, lintable: Lintable) -> list[Lintable]:
         """Traverse children of a single file or folder."""
+        playbook_ds: AnsibleJSON
         if not lintable.path.exists():
             return []
         playbook_dir = str(lintable.path.parent)
         ansiblelint.utils.set_collections_basedir(lintable.path.parent)
-        add_all_plugin_dirs(playbook_dir or ".")
+        add_all_plugin_dirs(playbook_dir or ".")  # type: ignore[no-untyped-call]
         if lintable.kind == "role":
             playbook_ds = AnsibleMapping({"roles": [{"role": str(lintable.path)}]})
         elif lintable.kind == "plugin":
@@ -564,9 +545,9 @@ class Runner:
             try:
                 playbook_ds = ansiblelint.utils.parse_yaml_from_file(str(lintable.path))
             except AnsibleError as exc:
-                msg = f"Loading {lintable.filename} caused an {type(exc).__name__} exception: {exc}, file was ignored."
-                _logger.exception(msg)
-                return []
+                raise MatchError(
+                    lintable=lintable, rule=self.rules["load-failure"]
+                ) from exc
         results = []
         # playbook_ds can be an AnsibleUnicode string, which we consider invalid
         if isinstance(playbook_ds, str):
@@ -587,7 +568,7 @@ class Runner:
                 # Repair incorrect paths obtained when old syntax was used, like:
                 # - include: simpletask.yml tags=nginx
                 valid_tokens = []
-                for token in split_args(path_str):
+                for token in split_args(path_str):  # type: ignore[no-untyped-call]
                     if "=" in token:
                         break
                     valid_tokens.append(token)
@@ -631,7 +612,7 @@ class Runner:
             "ansible.builtin.import_tasks": handlers.include_children,
         }
         (k, v) = item
-        add_all_plugin_dirs(str(basedir.resolve()))
+        add_all_plugin_dirs(str(basedir.resolve()))  # type: ignore[no-untyped-call]
 
         if k in delegate_map and v:
             v = template(
@@ -694,14 +675,14 @@ def threads() -> int:
     if os.path.exists(cpu_max_fname):
         # cgroup v2
         # https://www.kernel.org/doc/html/latest/admin-guide/cgroup-v2.html
-        with open(cpu_max_fname, encoding="utf-8") as fh:
+        with open(cpu_max_fname, encoding="utf-8") as fh:  # pragma: no cover
             cpu_quota_us, cpu_period_us = fh.read().strip().split()
     elif os.path.exists(cfs_quota_fname) and os.path.exists(cfs_period_fname):
         # cgroup v1
         # https://www.kernel.org/doc/html/latest/scheduler/sched-bwc.html#management
-        with open(cfs_quota_fname, encoding="utf-8") as fh:
+        with open(cfs_quota_fname, encoding="utf-8") as fh:  # pragma: no cover
             cpu_quota_us = fh.read().strip()
-        with open(cfs_period_fname, encoding="utf-8") as fh:
+        with open(cfs_period_fname, encoding="utf-8") as fh:  # pragma: no cover
             cpu_period_us = fh.read().strip()
     else:
         # No Cgroup CPU bandwidth limit (e.g. non-Linux platform)
